# Generated by roxygen2: do not edit by hand

export(clusterSOM)
export(clusterX)
export(finalSOM)
export(generatePlot)
export(getClusterData)
export(loadMatrix)
export(optimalSOM)
import(dplyr)
import(kohonen)
importFrom(RColorBrewer,brewer.pal)
importFrom(aweSOM,somQuality)
importFrom(fpc,cluster.stats)
importFrom(grDevices,colorRampPalette)
importFrom(kohonen,som)
importFrom(kohonen,somgrid)
importFrom(maptree,kgs)
importFrom(stats,cutree)
importFrom(stats,dist)
importFrom(stats,hclust)
importFrom(stats,rect.hclust)
importFrom(stats,sd)
importFrom(utils,read.csv)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
